from datetime import datetime
from equipment.framework.Log.AbstractLog import AbstractLog
from equipment.framework.Config.AbstractConfig import AbstractConfig
from equipment.framework.Queue.AbstractQueue import AbstractQueue
from equipment.framework.Queue.SyncQueue import SyncQueue
from equipment.framework.Queue.RedisQueue import RedisQueue


class QueueFactory(AbstractQueue):
    def __init__(self, config: AbstractConfig, log: AbstractLog):
        driver_name = config.get('QUEUE', 'driver')

        if driver_name == 'sync':
            self.driver = SyncQueue(config, log)
        elif driver_name == 'redis':
            self.driver = RedisQueue(config, log)
        else:
            error = f'Queue driver "{driver_name}" is not supported'
            log.error(error)
            raise NotImplementedError(error)

    def push(self, method, *args, **kwargs) -> bool:
        return self.driver.push(method, *args, **kwargs)

    def pushOn(self, date: datetime, method, *args, **kwargs) -> bool:
        return self.driver.pushOn(date, method, *args, **kwargs)



import os
from sqlalchemy import create_engine
from equipment.framework.Connection.SQLAlchemyConnection import SQLAlchemyConnection
from equipment.framework.Config.AbstractConfig import AbstractConfig
from equipment.framework.Log.AbstractLog import AbstractLog


class SQLiteConnection(SQLAlchemyConnection):
    def __init__(self, config: AbstractConfig, log: AbstractLog, name: str = 'CONNECTION_SQLITE'):
        super().__init__(config=config, log=log)
        self.memory = ':memory:'
        self.name = name

    def connect(self) -> bool:
        try:
            path = self.config.get(self.name, 'path')
            db = path if path == self.memory else os.path.join(
                os.path.dirname(os.path.realpath(__file__)),
                '../../',
                path
            )

            if db != self.memory and not os.path.isfile(db):
                raise FileNotFoundError(db)

            self.connection = 'sqlite:///' + db
            self.engine = create_engine(self.connection)

            self.log.debug(self.engine)

            return True
        except Exception as e:
            self.log.error(e, exc_info=True)
            return False



import unittest
from unittest.mock import patch
import neo4j
from equipment.framework.Connection.AbstractConnection import AbstractConnection
from equipment.framework.Connection.Neo4JConnection import Neo4JConnection
from equipment.framework.tests.TestCase import TestCase


class Neo4JConnectionTest(TestCase):
    def setUp(self):
        super().setUp()
        self.neo4j = Neo4JConnection(self.app.config(), self.app.log())

    def test_extends_from_abstract_Connection(self):
        self.assertTrue(
            isinstance(self.neo4j, AbstractConnection)
        )

    def test_returns_instance(self):
        with patch.object(neo4j.GraphDatabase, 'driver', return_value={}):
            self.assertTrue(
                isinstance(
                    self.neo4j.factory(),
                    type({})
                )
            )

    def test_connection_works(self):
        with patch.object(neo4j.GraphDatabase, 'driver', return_value={}):
            self.assertTrue(
                self.neo4j.connect()
            )

    def test_connection_fails(self):
        with patch.object(neo4j.GraphDatabase, 'driver', side_effect=Exception()):
            self.assertFalse(
                self.neo4j.connect()
            )


if __name__ == '__main__':
    unittest.main()



from typing import Any
from equipment.framework.Config.LocalConfig import LocalConfig
from equipment.framework.Config.AbstractConfig import AbstractConfig
from equipment.framework.Environment.AbstractEnvironment import AbstractEnvironment


class ConfigFactory(AbstractConfig):
    def __init__(self, env: AbstractEnvironment):
        self.driver = LocalConfig(env)

    def load(self) -> None:
        self.driver.load()

    def reload(self) -> None:
        self.driver.reload()

    def set(self, section: str, key: str, value) -> None:
        self.driver.set(section, key, value)

    def get(self, section: str, key: str) -> Any:
        return self.driver.get(section, key)



from equipment.framework.Log.AbstractLog import AbstractLog
from equipment.framework.Config.AbstractConfig import AbstractConfig
from equipment.framework.Queue.AbstractQueue import AbstractQueue


class SQSQueue(AbstractQueue):
    def __init__(self, config: AbstractConfig, log: AbstractLog):
        self.config = config
        self.log = log



import unittest
from datetime import datetime
from equipment.framework.Queue.AbstractQueue import AbstractQueue
from equipment.framework.Queue.SyncQueue import SyncQueue
from equipment.framework.tests.TestCase import TestCase


class SyncQueueTest(TestCase):
    def setUp(self):
        super().setUp()
        self.queue = SyncQueue(
            config=self.app.config(),
            log=self.app.log(),
        )

    def test_extends_from_abstract_queue(self):
        with self.app.queue.override(self.queue):
            self.assertTrue(
                isinstance(self.app.queue(), AbstractQueue)
            )

    def test_enqueues_methods(self):
        with self.app.queue.override(self.queue):
            def pass_test():
                return True

            def fail_test():
                raise Exception

            self.assertTrue(
                self.queue.push(pass_test)
            )

            self.assertFalse(
                self.queue.push(fail_test)
            )

            self.assertTrue(
                self.queue.pushOn(datetime.now(), pass_test)
            )

            self.assertFalse(
                self.queue.pushOn(datetime.now(), fail_test)
            )


if __name__ == '__main__':
    unittest.main()



#!/usr/bin/env python

from equipment.framework import equipment

app = equipment()

app.log().info(
    f'''

    Welcome to {app.config().get('APP', 'name')}

    This example shows how to read and write
    files with the storage module.
    '''
)

file = 'test.txt'

app.storage().write(file, 'test')

if not app.storage().exists(file):
    raise RuntimeError(f'{file} has not been created!')

if app.storage().read(file) != 'test':
    raise RuntimeError(f'{file} has not been read!')

if not app.storage().remove(file):
    raise RuntimeError(f'{file} has not been deleted!')



import mail1
from equipment.framework.Log.AbstractLog import AbstractLog
from equipment.framework.Config.AbstractConfig import AbstractConfig
from equipment.framework.Mail.AbstractMail import AbstractMail
from typing import Union
from equipment.framework.Mail.Email.Email import Email
from equipment.framework.Mail.Email.EmailFactory import EmailFactory


class SMTPMail(AbstractMail):
    def __init__(self, config: AbstractConfig, log: AbstractLog):
        self.config = config
        self.log = log

    def send(self, email: Union[Email, EmailFactory]) -> bool:
        if isinstance(email, EmailFactory):
            email = email.make()

        try:
            mail1.send(
                subject=email.subject,
                text=email.text,
                text_html=email.html,
                sender=email.sender,
                recipients=email.recipients,
                cc=email.cc,
                bcc=email.bcc,
                attachments=email.attachments,
                smtp_host=self.config.get('MAIL_SMTP', 'host'),
                smtp_port=int(self.config.get('MAIL_SMTP', 'port')),
                username=self.config.get('MAIL_SMTP', 'user'),
                password=self.config.get('MAIL_SMTP', 'password')
            )

            return True
        except Exception as e:
            self.log.error(e, exc_info=True)
            return False



import time
import unittest
from unittest.mock import patch
import schedule
from equipment.framework.Scheduler.AbstractScheduler import AbstractScheduler
from equipment.framework.Scheduler.Scheduler import Scheduler
from equipment.framework.tests.TestCase import TestCase


class SchedulerTest(TestCase):
    def setUp(self):
        super().setUp()

        self.scheduler = Scheduler(
            config=self.app.config(),
            log=self.app.log()
        )
        self.scheduler.should_exit = True

    def test_returns_none(self):
        with patch.object(schedule.Scheduler, 'run_pending', return_value=None):
            with patch.object(time, 'sleep', return_value=None):
                self.assertIsNone(self.scheduler.run())


if __name__ == '__main__':
    unittest.main()



import unittest
from equipment.framework.Connection.AbstractConnection import AbstractConnection
from equipment.framework.tests.TestCase import TestCase


class AbstractConnectionTest(TestCase):
    def test_abstract_methods(self):
        class TestConnection(AbstractConnection):
            pass

        with self.assertRaises(NotImplementedError):
            TestConnection().connect()

        with self.assertRaises(NotImplementedError):
            TestConnection().load()

        with self.assertRaises(NotImplementedError):
            TestConnection().reload()


if __name__ == '__main__':
    unittest.main()



import unittest
from unittest.mock import patch
from equipment.framework.tests.TestCase import TestCase
from equipment.framework.helpers import dump


class DumpHelperTest(TestCase):
    @patch('pprint.pformat')
    # pylint: disable=unused-argument
    def test_dump(self, mock_pformat):
        self.assertIsNone(dump('foo'))


if __name__ == '__main__':
    unittest.main()



import unittest
from equipment.framework.Environment.AbstractEnvironment import AbstractEnvironment
from equipment.framework.Environment.LocalEnvironment import LocalEnvironment
from equipment.framework.tests.TestCase import TestCase


class LocalEnvironmentTest(TestCase):
    def setUp(self):
        super().setUp()
        self.env = LocalEnvironment()

    def test_extends_from_abstract_environment(self):
        with self.app.environment.override(self.env):
            self.assertTrue(
                isinstance(self.app.environment(), AbstractEnvironment)
            )

    def test_returns_list_with_env_variables(self):
        with self.app.environment.override(self.env):
            result = self.app.environment().all()

            self.assertEqual(
                type(result),
                type([])
            )

            if len(result) > 0:
                self.assertEqual(
                    type(result[0]),
                    type({})
                )


if __name__ == '__main__':
    unittest.main()



import unittest
from equipment.framework.Config.AbstractConfig import AbstractConfig
from equipment.framework.tests.TestCase import TestCase


class AbstractConfigTest(TestCase):
    def test_abstract_methods(self):
        class TestConfig(AbstractConfig):
            pass

        with self.assertRaises(NotImplementedError):
            TestConfig().reload()

        with self.assertRaises(NotImplementedError):
            TestConfig().set('foo', 'bar', 'xyz')

        with self.assertRaises(NotImplementedError):
            TestConfig().get('foo', 'bar')


if __name__ == '__main__':
    unittest.main()



import unittest
from datetime import datetime
from equipment.framework.Queue.AbstractQueue import AbstractQueue
from equipment.framework.tests.TestCase import TestCase


class AbstractQueueTest(TestCase):
    def test_abstract_methods(self):
        class TestQueue(AbstractQueue):
            pass

        def test_method():
            return True

        with self.assertRaises(NotImplementedError):
            TestQueue().push(test_method)

        with self.assertRaises(NotImplementedError):
            TestQueue().pushOn(datetime.now(), test_method)


if __name__ == '__main__':
    unittest.main()



import fnmatch
import os
from typing import Any, Optional
from configparser import RawConfigParser
from equipment.framework.Config.AbstractConfig import AbstractConfig
from equipment.framework.helpers import base_path
from equipment.framework.Environment.AbstractEnvironment import AbstractEnvironment


class LocalConfig(AbstractConfig):
    def __init__(self, env: AbstractEnvironment, relative_path: str = 'config'):
        self.env = env
        self.config = None  # type: Optional[RawConfigParser]
        self.pattern = '*.conf'
        self.env_prefix = 'env:'
        self.path = os.path.join(
            os.path.dirname(os.path.realpath(__file__)),
            str(base_path(relative_path))
        )

    def load(self) -> None:
        if self.config is None:
            self.reload()

    def reload(self) -> None:
        self.config = RawConfigParser()

        for file in os.listdir(self.path):
            file = os.path.join(self.path, file)

            if os.path.isfile(file) and fnmatch.fnmatch(file, self.pattern):
                self.config.read(file)

    def set(self, section: str, key: str, value) -> None:
        self.load()

        return self.config.set(section, key, value)

    def get(self, section: str, key: str) -> Any:
        self.load()

        value = self.config.get(section, key)

        real_value = self.env.get(
            value.lstrip(self.env_prefix)
        ) if value.startswith(self.env_prefix) else value

        try:
            return eval(real_value)
        except Exception:
            return real_value



import unittest
from click.testing import CliRunner
from equipment.project.app.Commands.commands import example
from app.Commands.ExampleCommand import ExampleCommand
from tests.TestCase import TestCase

# Check: https://click.palletsprojects.com/en/8.0.x/testing/#testing-click-applications


class test_ExampleCommand(TestCase):
    def test_command_invoke(self):
        runner = CliRunner()
        result = runner.invoke(example)

        self.assertTrue(result.exit_code == 0)
        self.assertTrue(isinstance(result.output, str))

    def test_command_class(self):
        self.assertIsNone(
            ExampleCommand().run()
        )


if __name__ == '__main__':
    unittest.main()



from sqlalchemy import engine
from sqlalchemy.orm import sessionmaker
from sqlalchemy.orm.session import Session
from equipment.framework.Config.AbstractConfig import AbstractConfig
from equipment.framework.Connection.AbstractConnection import AbstractConnection
from equipment.framework.Log.AbstractLog import AbstractLog


class SQLAlchemyConnection(AbstractConnection):
    def __init__(self, config: AbstractConfig, log: AbstractLog):
        self.config = config
        self.log = log
        self.engine = None
        self.connection = None

    def load(self) -> None:
        if self.engine is None:
            self.reload()

    def reload(self) -> None:
        self.connect()

    # Connections are handled on specific implementations like SQLiteConnection, etc.
    def connect(self) -> bool:
        raise NotImplementedError

    def url(self) -> str:
        self.load()
        return self.connection

    def factory(self) -> engine.base.Engine:
        self.load()
        return self.engine

    def session(self) -> Session:
        self.load()
        _session = sessionmaker(bind=self.engine)
        return _session()



import logging
from logging import StreamHandler
from sys import stdout, stderr
from equipment.framework.Log.NativeLog import NativeLog


class ConsoleLog(NativeLog):
    def get_handlers(self) -> list:
        return [
            StreamHandler(stdout),
            StreamHandler(stderr)
        ]

    def get_level(self) -> int:
        level = self.config.get('LOG_CONSOLE', 'level')
        return getattr(logging, level if level is not None else 'DEBUG')

    def get_name(self) -> str:
        return self.config.get('LOG_CONSOLE', 'name')



import unittest
from unittest.mock import patch
import mail1
from equipment.framework.Mail.Email.HTMLEmailFactory import HTMLEmailFactory
from equipment.framework.Mail.AbstractMail import AbstractMail
from equipment.framework.Mail.SMTPMail import SMTPMail
from equipment.framework.tests.TestCase import TestCase


class SMTPMailTest(TestCase):
    def setUp(self):
        super().setUp()
        self.mail = SMTPMail(
            config=self.app.config(),
            log=self.app.log(),
        )

    def test_extends_from_abstract_Mail(self):
        with self.app.mail.override(self.mail):
            self.assertTrue(
                isinstance(self.app.mail(), AbstractMail)
            )

    def test_email_success(self):
        with self.app.mail.override(self.mail):
            with patch.object(mail1, 'send', return_value=None):
                class MyEmail(HTMLEmailFactory):
                    subject = 'My Email Subject'
                    text = 'My Email Text'
                    html = '<p>My Email <b>HTML</b></p>'
                    sender = 'sender@example.com'
                    recipients = ['test@test.com']
                    cc = ['cc@example.com']
                    bcc = ['bcc@example.com']
                    attachments = {}

                self.assertTrue(
                    self.app.mail().send(MyEmail())
                )

    def test_email_failure(self):
        with self.app.mail.override(self.mail):
            with patch.object(mail1, 'send', side_effect=Exception()):
                class MyEmail(HTMLEmailFactory):
                    subject = 'My Email Subject'
                    text = 'My Email Text'
                    html = '<p>My Email <b>HTML</b></p>'
                    sender = 'sender@example.com'
                    recipients = ['test@test.com']
                    cc = ['cc@example.com']
                    bcc = ['bcc@example.com']
                    attachments = {}

                self.assertFalse(
                    self.app.mail().send(MyEmail())
                )


if __name__ == '__main__':
    unittest.main()



import unittest
from equipment.framework.tests.TestCase import TestCase
from equipment.framework.helpers import raise_unless


class RaseUnlessHelperTest(TestCase):
    def test_true(self):
        with self.assertRaises(ImportError):
            raise_unless(False, ImportError('foo'))

    def test_false(self):
        self.assertIsNone(raise_unless(True, ImportError('foo')))


if __name__ == '__main__':
    unittest.main()



import unittest
from equipment.framework.tests.TestCase import TestCase
from equipment.framework import equipment


class EquipmentHelperTest(TestCase):
    def test_equipment_function(self):
        self.assertIsNotNone(
            equipment('equipment.framework.App.Container')
        )


if __name__ == '__main__':
    unittest.main()



import unittest
from equipment.framework.Log.AbstractLog import AbstractLog
from equipment.framework.Log.NativeLog import NativeLog
from equipment.framework.tests.TestCase import TestCase


class NativeLogTest(TestCase):
    def test_extends_from_abstract_log(self):
        with self.app.log.override(NativeLog(config=self.app.config())):
            self.assertTrue(
                isinstance(self.app.log(), AbstractLog)
            )

    def test_properties_are_not_implemented(self):
        with self.app.log.override(NativeLog(config=self.app.config())):
            with self.assertRaises(NotImplementedError):
                self.app.log().get_handlers()

            with self.assertRaises(NotImplementedError):
                self.app.log().get_level()

            with self.assertRaises(NotImplementedError):
                self.app.log().get_name()


if __name__ == '__main__':
    unittest.main()



import unittest
from unittest.mock import MagicMock, patch
import sqlalchemy
from equipment.framework.Connection.AbstractConnection import AbstractConnection
from equipment.framework.Connection.SQLiteConnection import SQLiteConnection
from equipment.framework.tests.TestCase import TestCase


class SQLiteConnectionTest(TestCase):
    def setUp(self):
        super().setUp()
        config = self.app.config()
        config.set('CONNECTION_SQLITE', 'path', ':memory:')

        self.sql = SQLiteConnection(
            config=config,
            log=self.app.log()
        )

    def test_extends_from_abstract_Connection(self):
        self.assertTrue(
            isinstance(self.sql, AbstractConnection)
        )

    def test_returns_instance(self):
        self.assertTrue(
            isinstance(
                self.sql.factory(),
                sqlalchemy.engine.base.Engine
            )
        )

    def test_connection_works(self):
        with patch.object(sqlalchemy, 'create_engine', return_value={}):
            self.assertTrue(
                self.sql.connect()
            )

    def test_connection_fails(self):
        with patch.object(sqlalchemy, 'create_engine', return_value={}):
            self.sql.log.debug = MagicMock(side_effect=Exception())

            self.assertFalse(
                self.sql.connect()
            )


if __name__ == '__main__':
    unittest.main()



import os
from codecs import open as _open
from datetime import datetime
from os.path import abspath, dirname, isdir, isfile, join
from shutil import copyfile, copytree, ignore_patterns, move
from tempfile import gettempdir
from click import confirm, echo, style
from pkg_resources import get_distribution
from equipment.console.Commands.AbstractCommand import AbstractCommand


class NewCommand(AbstractCommand):
    name: str
    source: str
    destination: str
    already_exists: bool
    confirmation: bool

    def __init__(self, name: str) -> None:
        self.name = name

    def run(self, *args, **kwargs) -> None:
        self.source = abspath(join(dirname(__file__), f'..{os.sep}..{os.sep}project'))  # nopep8
        self.destination = f'{os.getcwd()}{os.sep}{self.name}'
        self.already_exists = isdir(self.destination)
        self.confirmation = confirm(f'Directory "{self.destination}" already exists. Do you want to override it?') if self.already_exists else True  # nopep8

        if not self.confirmation:
            echo(style('Skip', fg='yellow'))
            return None

        self._handle_existing_directory()
        self._copy_project_folder()
        self._generate_environment_file()
        self._replace_requirements_file()

        echo(style('Done!', fg='green'))
        echo(style(f'run "cd {self.destination} && pip install -r requirements.txt"', fg='green'))  # nopep8

    def _handle_existing_directory(self) -> None:
        if self.already_exists:
            temporal_destination = f'{gettempdir()}{os.sep}{datetime.now()}{self.name}'
            move(self.destination, temporal_destination)

    def _copy_project_folder(self) -> None:
        echo(style('Creating folder project...', fg='green'))

        copytree(
            self.source,
            self.destination,
            ignore=ignore_patterns('*.pyc', 'tmp*', '*__pycache__*', '*.env', '*.coverage')  # nopep8
        )

    def _generate_environment_file(self) -> None:
        echo(style('Generating environment file...', fg='green'))

        environment_file = f'{self.destination}{os.sep}.env'

        if isfile(environment_file):
            echo(style(f'WARNING: "{environment_file}" already exists. Skip...', fg='yellow'))  # nopep8
            return None

        copyfile(
            f'{self.destination}{os.sep}.env.example',
            environment_file
        )

    def _replace_requirements_file(self) -> None:
        requirements_file = f'{self.destination}{os.sep}requirements.txt'
        data = ''

        with _open(requirements_file, 'r') as f:
            data = f.read()

        try:
            replaced = f'equipment=={get_distribution("equipment").version}'
        except Exception as e:
            echo(style(f'WARNING: could not get equipment version. Error: "{str(e)}"', fg='yellow'))  # nopep8
            replaced = 'equipment'

        data = data.replace('-e ../../', replaced)

        with _open(requirements_file, 'w') as f:
            f.write(data)



import logging
from logging import StreamHandler
from sys import stdout
from pygelf import GelfUdpHandler
from equipment.framework.Log.NativeLog import NativeLog


class GELFLog(NativeLog):
    def get_handlers(self) -> list:
        return [
            GelfUdpHandler(
                host=self.config.get('LOG_GELF', 'host'),
                port=self.config.get('LOG_GELF', 'port'),
                _app_name=self.config.get('APP', 'name')
            ),
            StreamHandler(stdout)
        ]

    def get_level(self) -> int:
        return getattr(logging, self.config.get('LOG_GELF', 'level'))

    def get_name(self) -> str:
        return self.config.get('LOG_GELF', 'name')



from os import sep
from equipment.framework.Mail.Email.Email import Email
from equipment.framework.Mail.Email.EmailFactory import EmailFactory
from jinja2 import Environment, FileSystemLoader, select_autoescape
from jinja_markdown import MarkdownExtension
from premailer import transform
from html2text import html2text
from equipment.framework.helpers import base_path


class HTMLEmailFactory(EmailFactory):
    text = None  # type: str
    html = None  # type: str
    jinja = None  # type: Environment

    def load(self) -> None:
        if self.jinja is None:
            self.reload()

    def reload(self) -> None:
        self.jinja = Environment(
            loader=FileSystemLoader(
                str(base_path(f'resources{sep}views{sep}emails'))
            ),
            autoescape=select_autoescape()
        )

        self.jinja.add_extension(MarkdownExtension)

    # pylint: disable=dangerous-default-value
    def render(self, template: str, parameters: dict = {}) -> None:
        self.load()

        self.html = transform(
            (self.jinja.get_template(template)).render(parameters)
        )

        self.text = html2text(self.html)

    def make(self) -> Email:
        if self.html is None:
            raise ValueError('"html" cannot be None')

        return super().make()



import unittest
from equipment.framework.tests.TestCase import TestCase
from equipment.framework.helpers import app
from equipment.framework.Exceptions.ContainerModuleNotFound import ContainerModuleNotFound


class ContainerModuleNotFoundTest(TestCase):
    def test_error_is_raised(self):
        with self.assertRaises(ContainerModuleNotFound):
            app('foo', autodiscover=False)


if __name__ == '__main__':
    unittest.main()



import logging
from logging.handlers import TimedRotatingFileHandler
from equipment.framework.Log.NativeLog import NativeLog


class LocalLog(NativeLog):
    def get_handlers(self) -> list:
        return [
            TimedRotatingFileHandler(
                filename=self.config.get('LOG_LOCAL', 'path'),
                when='D',
                interval=1,
                delay=self.config.get('LOG_LOCAL', 'delay')
            )
        ]

    def get_level(self) -> int:
        level = self.config.get('LOG_LOCAL', 'level')
        return getattr(logging, level if level is not None else 'DEBUG')

    def get_name(self) -> str:
        return self.config.get('LOG_LOCAL', 'name')



#!/usr/bin/env python

from equipment.framework import equipment
from app.Mail.WelcomeEmail import WelcomeEmail

app = equipment()


app.log().info(
    f'''

    Welcome to {app.config().get('APP', 'name')}

    Do you to send an email?

    Go to the root folder and run:

    $ rm main.py && mv examples/example_email.py main.py
    $ py main.py
    '''
)

email = WelcomeEmail()
email.sender = 'example@example.com'
email.recipients = 'test@test.com'
email.user_name = 'John Doe'

app.mail().send(email)



#!/usr/bin/env python

from equipment.framework import equipment
import matplotlib.pyplot as plt
import numpy as np

app = equipment()

app.log().info(
    f'''

    Welcome to {app.config().get('APP', 'name')}

    Do you to work with matplotlib?

    Go to the root folder and run:

    $ pip install matplotlib
    $ pip install numpy
    $ rm main.py && mv examples/example_matplotlib.py main.py
    $ py main.py
    '''
)

# Create CSV with data
app.storage().write(
    'data.csv',
    '''1, 5
2, 3
3, 4
4, 7
5, 4
6, 3
7, 5
8, 7
9, 4
10, 4'''
)

x, y = np.loadtxt(app.storage().path('data.csv'), delimiter=',', unpack=True)

plt.plot(x, y, label='Example')
plt.xlabel('x')
plt.ylabel('y')
plt.title('Matplotlib example')
plt.legend()
plt.show()



import unittest
from equipment.framework.Log.AbstractLog import AbstractLog
from equipment.framework.tests.TestCase import TestCase


class AbstractLogTest(TestCase):
    def test_abstract_methods(self):
        class TestLog(AbstractLog):
            pass

        with self.assertRaises(NotImplementedError):
            TestLog().debug()

        with self.assertRaises(NotImplementedError):
            TestLog().info()

        with self.assertRaises(NotImplementedError):
            TestLog().warning()

        with self.assertRaises(NotImplementedError):
            TestLog().error()

        with self.assertRaises(NotImplementedError):
            TestLog().critical()


if __name__ == '__main__':
    unittest.main()



import unittest
import os
from shutil import move, rmtree
from os.path import isdir, isfile
from tempfile import gettempdir
from datetime import datetime
from codecs import open as _open
from unittest.mock import patch
from click.testing import CliRunner
from equipment.console.Commands.NewCommand import NewCommand
from equipment.console import new
from equipment.console.tests.TestCase import TestCase


class NewCommandTest(TestCase):
    def test_command_invoke(self):
        project = '__pycache__'  # ensure it is always ignored
        print(f'{self.tests_path}{os.sep}{project}')

        with patch.object(os, 'getcwd', return_value=self.tests_path):
            runner = CliRunner()
            result = runner.invoke(new, [project])
            self.assertTrue(result.exit_code == 0)

        rmtree(f'{self.tests_path}{os.sep}{project}', ignore_errors=False)

    def test_command_class(self):
        project = '__pycache__'  # ensure it is always ignored
        full_path = f'{self.tests_path}{os.sep}{project}'

        if isdir(full_path):
            move(full_path, f'{gettempdir()}{os.sep}{datetime.now()}{os.sep}{project}')  # nopep8

        self.assertFalse(isdir(full_path))

        with patch.object(os, 'getcwd', return_value=self.tests_path):
            self.assertIsNone(NewCommand(project).run())

        self.assertTrue(isdir(full_path))

        self.assertTrue(isfile(f'{full_path}{os.sep}.env'))

        requirements_file = f'{full_path}{os.sep}requirements.txt'

        self.assertTrue(isfile(requirements_file))

        with _open(requirements_file, 'r') as f:
            self.assertTrue('equipment==' in f.read())

        rmtree(full_path, ignore_errors=True)


if __name__ == '__main__':
    unittest.main()



from typing import Any
from equipment.framework.Environment.AbstractEnvironment import AbstractEnvironment
from equipment.framework.Environment.LocalEnvironment import LocalEnvironment


class EnvironmentFactory(AbstractEnvironment):
    def __init__(self):
        self.driver = LocalEnvironment()

    def get(self, key: str) -> Any:
        return self.driver.get(key)

    def set(self, key: str, value) -> None:
        self.driver.set(key, value)

    def all(self) -> list:
        return self.driver.all()



#!/usr/bin/env python

from app.Jobs.ExampleJob import ExampleJob

print('''

Instead of loading the equipment
you can may Jobs that already
load the framework

''')

ExampleJob.dispatchSync('Running job')

ExampleJob.dispatch('Running job on queue')



#!/usr/bin/env python

from equipment.framework import equipment


app = equipment()

app.log().info(
    f'''

    Welcome to {app.config().get('APP', 'name')}

    Do you to access a SQL Database, a MongoDB instance, or a Redis cluster?

    Go to the root folder and run:

    $ rm main.py && mv examples/example_connection.py main.py
    $ py main.py
    '''
)

# SQL (SQLAlchemy connection)
with app.sql().factory().begin() as connection:
    result = connection.execute('SELECT 1')
    app.log().info(result)

# MongoDB connection
result = app.mongo().factory().products.insert_one(
    {'product': 'PS5', 'stock': 0}
)

app.log().info(result)

# Redis connection
app.redis().factory().set('foo', 'bar')
app.log().info(
    app.redis().factory().get('foo')
)


# Neo4J connection

# You might have a logging issue with the following message:
# "NameError: name 'open' is not defined"
# Change your logging level from DEBUG to INFO as a workaround.
# Check https://bugs.python.org/issue39513 for more details

with app.neo4j().factory().session() as session:
    app.log().info(
        session.run('MATCH (n) RETURN n LIMIT 5')
    )



from dependency_injector.providers import Singleton
from app.Scheduler.Scheduler import Scheduler
from equipment.framework.App.Container import Container as E
from equipment.framework.Connection.SQLiteConnection import SQLiteConnection


class Container(E):
    scheduler = Singleton(Scheduler, E.config, E.log)  # nopep8

    # Available SQL connections: SQLServerConnection, MySQLConnection, PostgreSQLConnection
    sql = Singleton(SQLiteConnection, E.config, E.log)

    # Other Connections are also available:
    # mongo = Singleton(MongoDBConnection, E.config, E.log)
    # neo4j = Singleton(Neo4JConnection, E.config, E.log)
    # redis = Singleton(RedisConnection, E.config, E.log)

    # CUSTOMIZE CONNECTIONS:
    #
    # You can create your own connection variant by specifying the config
    # section where the connection parameters should be read from
    #
    # $ my_sqlite = Singleton(SQLiteConnection, config, log, 'CONFIG_SECTION')

    # APPEND CUSTOM SINGLETONS
    #
    # Custom classes and functions can be provided by the container
    #
    # $ myservice = Singleton(MyService, config, log)
    #
    # Now you can call app.myservice() to get the singleton instance



import unittest
from equipment.framework.Scheduler.AbstractScheduler import AbstractScheduler
from equipment.framework.tests.TestCase import TestCase


class AbstractSchedulerTest(TestCase):
    def test_abstract_methods(self):
        class TestScheduler(AbstractScheduler):
            pass

        with self.assertRaises(NotImplementedError):
            TestScheduler().run()


if __name__ == '__main__':
    unittest.main()



import unittest
from unittest.mock import MagicMock, patch
import pymongo
from equipment.framework.Connection.AbstractConnection import AbstractConnection
from equipment.framework.Connection.MongoDBConnection import MongoDBConnection
from equipment.framework.tests.TestCase import TestCase


class MongoDBConnectionTest(TestCase):
    def setUp(self):
        super().setUp()
        self.mongo = MongoDBConnection(self.app.config(), self.app.log())

    def test_extends_from_abstract_Connection(self):
        self.assertTrue(
            isinstance(self.mongo, AbstractConnection)
        )

    def test_connection_works(self):
        with patch.object(pymongo.MongoClient, '__init__', return_value=None):
            self.assertTrue(
                self.mongo.connect()
            )

    def test_connection_fails(self):
        self.mongo.client = MagicMock()
        self.mongo.log.debug = MagicMock(side_effect=Exception())

        self.assertFalse(
            self.mongo.connect()
        )


if __name__ == '__main__':
    unittest.main()



from app.Jobs.ExampleJob import ExampleJob
from equipment.framework.Scheduler.Scheduler import Scheduler as BScheduler

# Schedule setup (https://schedule.readthedocs.io/en/stable/)


class Scheduler(BScheduler):
    def run(self) -> None:
        self.schedule.every(1).seconds.do(
            self.log.info, 'Logging from scheduler'
        )

        self.schedule.every(1).seconds.do(
            ExampleJob.dispatchSync, 'not enqueued message'
        )

        self.schedule.every(1).seconds.do(
            ExampleJob.dispatch, 'enqueued message'
        )

        super().run()



import abc


class AbstractConnection(abc.ABC):
    def connect(self) -> bool:
        raise NotImplementedError

    def load(self) -> None:
        raise NotImplementedError

    def reload(self) -> None:
        raise NotImplementedError



import unittest
from equipment.framework.tests.TestCase import TestCase
from equipment.framework.helpers import module


class ModuleHelperTest(TestCase):
    def test_module_helper_returns_module(self):
        result = module('equipment.framework.tests.TestCase')
        self.assertIsNotNone(result)

    def test_module_helper_returns_none_when_module_not_found(self):
        result = module('this_module_does_not_exist')
        self.assertIsNone(result)


if __name__ == '__main__':
    unittest.main()



from equipment.framework.Mail.Email.Email import Email
from equipment.framework.Mail.Email.HTMLEmailFactory import HTMLEmailFactory


class WelcomeEmail(HTMLEmailFactory):
    user_name = None  # type: str
    registration_link = 'https://example.com'

    def make(self) -> Email:
        self.render('welcome.html', {
            'user_name': self.user_name,
            'registration_link': self.registration_link,
        })

        self.subject = f'Welcome, {self.user_name}!'

        return super().make()



import os
import unittest
from faker import Faker
from equipment.framework.helpers import app
from equipment.framework.Log.NoneLog import NoneLog
from equipment.framework.Config.LocalConfig import LocalConfig


class TestCase(unittest.TestCase):
    def setUp(self):
        super().setUp()

        # Access tests base path
        self.tests_path = os.path.dirname(os.path.abspath(__file__))

        # Global faker instance
        self.faker = Faker()

        # Initialize app
        self.app = app('equipment.framework.App.Container')

        # Override config
        self.app.config.override(LocalConfig(
            self.app.environment(),
            f'framework{os.sep}tests{os.sep}_stubs{os.sep}config'
        ))

        # Override logger
        self.app.log.override(NoneLog(config=self.app.config()))


if __name__ == '__main__':
    unittest.main()



import abc


class AbstractLog(abc.ABC):
    def debug(self, *args, **kwargs) -> None:
        raise NotImplementedError

    def info(self, *args, **kwargs) -> None:
        raise NotImplementedError

    def warning(self, *args, **kwargs) -> None:
        raise NotImplementedError

    def error(self, *args, **kwargs) -> None:
        raise NotImplementedError

    def critical(self, *args, **kwargs) -> None:
        raise NotImplementedError

    def get_handlers(self) -> list:
        raise NotImplementedError

    def get_level(self) -> int:
        raise NotImplementedError

    def get_name(self) -> str:
        raise NotImplementedError



from sys import exit as _exit
from time import sleep
import schedule
from equipment.framework.Config.AbstractConfig import AbstractConfig
from equipment.framework.Log.AbstractLog import AbstractLog
from equipment.framework.Scheduler.AbstractScheduler import AbstractScheduler


class Scheduler(AbstractScheduler):
    def __init__(self, config: AbstractConfig, log: AbstractLog):
        self.config = config
        self.log = log
        self.should_exit = False
        self.schedule = schedule.Scheduler()

    def run(self) -> None:
        self.log.info('Starting scheduler...')
        while True:
            try:
                self.schedule.run_pending()
                sleep(1)

                if self.should_exit:
                    break

            except KeyboardInterrupt:
                self.log.info('Stopping scheduler...')
                _exit()



import codecs
import os
from equipment.framework.Config.AbstractConfig import AbstractConfig
from equipment.framework.Log.AbstractLog import AbstractLog
from equipment.framework.Storage.AbstractStorage import AbstractStorage


class LocalStorage(AbstractStorage):
    def __init__(self, config: AbstractConfig, log: AbstractLog):
        self.config = config
        self.log = log

    def base_path(self) -> str:
        return os.path.join(
            os.path.dirname(os.path.realpath(__file__)),
            '../../',
            self.config.get('STORAGE_LOCAL', 'path')
        )

    def path(self, file: str) -> str:
        return os.path.join(
            self.base_path(),
            file
        )

    def write(self, file: str, data: str) -> bool:
        try:
            file = self.path(file)

            self.log.debug('LocalStorage@write file: ' + str(file))

            os.makedirs(
                os.path.dirname(file),
                exist_ok=True
            )

            with codecs.open(file, 'w') as filepath:
                filepath.write(data)

            return True
        except Exception as e:
            self.log.error(e, exc_info=True)
            return False

    def read(self, file: str) -> str:
        file = self.path(file)
        self.log.debug('file: ' + file)

        with codecs.open(file, 'r') as filepath:
            return filepath.read()

    def exists(self, file: str) -> bool:
        return os.path.isfile(self.path(file))

    def remove(self, file: str) -> bool:
        try:
            os.remove(self.path(file))
            return True
        except Exception as e:
            self.log.error(e, exc_info=True)
            return False

    def move(self, source: str, destination: str) -> bool:
        try:
            os.rename(
                self.path(source),
                self.path(destination)
            )
            return True
        except Exception as e:
            self.log.error(e, exc_info=True)
            return False

    def list(self, path: str) -> list:
        path = os.path.join(self.base_path(), path)

        if not os.path.isdir(path):
            raise NotADirectoryError(f'{path} is not a directory')

        return [file for file in os.listdir(path) if os.path.isfile(os.path.join(path, file))]  # nopep8



import unittest
from unittest.mock import MagicMock
from redis import Redis
from equipment.framework.Connection.AbstractConnection import AbstractConnection
from equipment.framework.tests.TestCase import TestCase
from equipment.framework.Connection.RedisConnection import RedisConnection


class RedisConnectionTest(TestCase):
    def setUp(self):
        super().setUp()
        self.redis = RedisConnection(self.app.config(), self.app.log())

    def test_extends_from_abstract_Connection(self):
        self.assertTrue(
            isinstance(self.redis, AbstractConnection)
        )

    def test_returns_instance(self):
        self.assertTrue(
            isinstance(self.redis.factory(), Redis)
        )

    def test_connection_works(self):
        self.assertTrue(
            self.redis.connect()
        )

    def test_connection_fails(self):
        self.redis.log.debug = MagicMock(side_effect=Exception())

        self.assertFalse(
            self.redis.connect()
        )


if __name__ == '__main__':
    unittest.main()



import unittest
from os import sep
from uuid import uuid4
from equipment.framework.tests.TestCase import TestCase
from equipment.framework.Config.AbstractConfig import AbstractConfig
from equipment.framework.Config.LocalConfig import LocalConfig


class LocalConfigTest(TestCase):
    def setUp(self):
        super().setUp()
        self.app.config.override(LocalConfig(
            self.app.environment(),
            f'framework{sep}tests{sep}_stubs{sep}config'
        ))

    def test_extends_from_abstract_config(self):
        self.assertTrue(
            isinstance(self.app.config(), AbstractConfig)
        )

    def test_it_reads_local_config_files(self):
        content = self.faker.name()
        self.assertIsInstance(content, str)

        self.app.config().set('APP', 'name', content)
        result = self.app.config().get('APP', 'name')

        self.assertEqual(result, content)

    def test_it_reads_environment_variables(self):
        content = 'BAR'
        self.app.environment().set('FOO', content)
        self.app.config().set('APP', 'name', 'env:FOO')

        result = self.app.config().get('APP', 'name')

        self.assertEqual(result, content)

    def test_it_reads_correct_types(self):
        section = str(uuid4())
        self.app.config().load()
        self.app.config().config.read_string('''
        [{section}]
        should_be_none = None
        should_be_int = 123
        should_be_string = asdf
        should_be_list = ['a','b','c']
        should_be_dict = {{'a': 123}}
        should_be_tuple = ('a', 'b', 'c')
        should_be_bool = True
        '''.format(section=section))

        self.assertEqual(
            type(None),
            type(self.app.config().get(section, 'should_be_none'))
        )

        self.assertEqual(
            type(123),
            type(self.app.config().get(section, 'should_be_int'))
        )

        self.assertEqual(
            type('asdf'),
            type(self.app.config().get(section, 'should_be_string'))
        )

        self.assertEqual(
            type(['a', 'b', 'c']),
            type(self.app.config().get(section, 'should_be_list'))
        )

        self.assertEqual(
            type({'a': 123}),
            type(self.app.config().get(section, 'should_be_dict'))
        )

        self.assertEqual(
            type(('a', 'b', 'c')),
            type(self.app.config().get(section, 'should_be_tuple'))
        )

        self.assertEqual(
            type(True),
            type(self.app.config().get(section, 'should_be_bool'))
        )


if __name__ == '__main__':
    unittest.main()



import unittest
import os
from pathlib import Path
from equipment.framework.tests.TestCase import TestCase
from equipment.framework.helpers import base_path


class BasePathHelperTest(TestCase):
    def test_base_path_returns_path_instance(self):
        result = base_path('foo', self.app)

        self.assertIsInstance(result, Path)
        self.assertTrue(str(result).endswith('foo'))

    def test_base_path_returns_expected_path(self):
        result = base_path('', self.app)

        self.assertIsInstance(result, Path)
        self.assertTrue(str(result).endswith('equipment'))

        self.assertTrue(os.path.isdir(str(result.joinpath('console'))))
        self.assertTrue(os.path.isdir(str(result.joinpath('project'))))
        self.assertTrue(os.path.isdir(str(result.joinpath('framework'))))


if __name__ == '__main__':
    unittest.main()



import logging
from logging import NullHandler
from equipment.framework.Log.NativeLog import NativeLog


class NoneLog(NativeLog):
    def get_handlers(self) -> list:
        return [NullHandler()]

    def get_level(self) -> int:
        return logging.NOTSET

    def get_name(self) -> str:
        return self.config.get('LOG_NONE', 'name')



import unittest
from faker import Faker
from equipment.framework.Environment.LocalEnvironment import LocalEnvironment
from equipment.framework.helpers import app


class TestCase(unittest.TestCase):
    def setUp(self):
        super().setUp()

        # Global faker instance
        self.faker = Faker()

        # Initialize app
        self.app = app()

        # Override environment
        self.app.environment.override(LocalEnvironment('.env.test'))


if __name__ == '__main__':
    unittest.main()



from redis import Redis
from rq import Queue
from equipment.framework.Log.AbstractLog import AbstractLog
from equipment.framework.Config.AbstractConfig import AbstractConfig
from equipment.framework.Queue.AbstractQueue import AbstractQueue


class RedisQueue(AbstractQueue):
    def __init__(self, config: AbstractConfig, log: AbstractLog):
        self.config = config
        self.log = log
        self.redis = None
        self.queue = None

    def load(self) -> None:
        if self.queue is None:
            self.reload()

    def reload(self) -> None:
        self.redis = Redis(
            host=self.config.get('QUEUE_REDIS', 'host'),
            port=self.config.get('QUEUE_REDIS', 'port'),
            db=self.config.get('QUEUE_REDIS', 'db'),
        )

        self.queue = Queue(connection=self.redis)

    def push(self, method, *args, **kwargs) -> bool:
        try:
            self.load()

            self.log.debug('RedisQueue@push method:')
            self.log.debug(method)
            self.log.debug('RedisQueue@push args:')
            self.log.debug(args)
            self.log.debug('RedisQueue@push kwargs:')
            self.log.debug(kwargs)

            self.queue.enqueue(
                f=method,
                args=args,
                kwargs=kwargs
            )

            return True
        except Exception as e:
            self.log.error(e, exc_info=True)
            return False



from datetime import datetime
from equipment.framework.Log.AbstractLog import AbstractLog
from equipment.framework.Config.AbstractConfig import AbstractConfig
from equipment.framework.Queue.AbstractQueue import AbstractQueue


class SyncQueue(AbstractQueue):
    def __init__(self, config: AbstractConfig, log: AbstractLog):
        self.config = config
        self.log = log

    def push(self, method, *args, **kwargs) -> bool:
        try:
            method(*args, **kwargs)
            return True
        except Exception as e:
            self.log.error(e, exc_info=True)
            return False

    def pushOn(self, date: datetime, method, *args, **kwargs) -> bool:
        # SyncQueue ignores specific dates
        return self.push(method, *args, **kwargs)



import unittest
from unittest.mock import patch
from equipment.framework.tests.TestCase import TestCase
from equipment.framework.helpers import print_unless


class PrintUnlessHelperTest(TestCase):
    @patch('builtins.print')
    def test_true(self, mock_print):
        print_unless(False, 'foo')
        mock_print.assert_called_with('foo')

    @patch('builtins.print')
    def test_false(self, mock_print):
        print_unless(True, 'foo')
        mock_print.assert_not_called()


if __name__ == '__main__':
    unittest.main()



import os
from codecs import open as _open
from os.path import abspath, dirname, isfile, join
from pathlib import Path
from click import confirm, echo, style
from equipment.console.Commands.AbstractCommand import AbstractCommand


class MakeJobCommand(AbstractCommand):
    name: str
    replacement: str
    jobs_path: str
    destination: str
    source: str
    confirmation: bool

    def __init__(self, name: str, replacement: str = '_REPLACEME_') -> None:
        self.name = name
        self.replacement = replacement

    def run(self, *args, **kwargs) -> None:
        echo(style(f'Creating {self.name} job...', fg='green'))

        self.jobs_path = f'{os.getcwd()}{os.sep}app{os.sep}Jobs'
        self.source = abspath(join(dirname(__file__), f'..{os.sep}stubs{os.sep}Job.py'))  # nopep8
        self.destination = f'{self.jobs_path}{os.sep}{self.name}.py'
        self.confirmation = confirm(f'Directory "{self.destination}" already exists. Do you want to override it?') if isfile(self.destination) else True  # nopep8

        if not self.confirmation:
            echo(style('Skip', fg='yellow'))
            return None

        self._ensureJobsDirectory()
        self._createFile()

        echo(style('Done!', fg='green'))

    def _ensureJobsDirectory(self) -> None:
        Path(self.jobs_path).mkdir(parents=True, exist_ok=True)

        init_file = f'{self.jobs_path}{os.sep}__init__.py'

        if not isfile(init_file):
            with _open(init_file, 'w') as f:
                f.write('')

    def _createFile(self) -> None:
        content = ''

        with _open(self.source, 'r') as source:
            content = source.read()

        with _open(self.destination, 'w') as destination:
            destination.write(content.replace(self.replacement, self.name))



import unittest
from equipment.framework.Environment.AbstractEnvironment import AbstractEnvironment
from equipment.framework.tests.TestCase import TestCase


class AbstractEnvironmentTest(TestCase):
    def test_abstract_methods(self):
        class TestEnvironment(AbstractEnvironment):
            pass

        with self.assertRaises(NotImplementedError):
            TestEnvironment().all()

        with self.assertRaises(NotImplementedError):
            TestEnvironment().set('foo', 'xyz')

        with self.assertRaises(NotImplementedError):
            TestEnvironment().get('foo')


if __name__ == '__main__':
    unittest.main()



from equipment.framework.Config.AbstractConfig import AbstractConfig
from equipment.framework.Log.AbstractLog import AbstractLog
from equipment.framework.Storage.AbstractStorage import AbstractStorage
from equipment.framework.Storage.LocalStorage import LocalStorage
from equipment.framework.Storage.S3Storage import S3Storage


class StorageFactory(AbstractStorage):
    def __init__(self, config: AbstractConfig, log: AbstractLog):
        driver_name = config.get('STORAGE', 'driver')

        if driver_name == 'local':
            self.driver = LocalStorage(config, log)
        elif driver_name == 's3':
            self.driver = S3Storage(config, log)
        else:
            error = f'Storage driver "{driver_name}" is not supported'
            log.error(error)
            raise NotImplementedError(error)

    def path(self, file: str) -> str:
        return self.driver.path(file)

    def write(self, file: str, data: str) -> bool:
        return self.driver.write(file, data)

    def read(self, file: str) -> str:
        return self.driver.read(file)

    def exists(self, file: str) -> bool:
        return self.driver.exists(file)

    def remove(self, file: str) -> bool:
        return self.driver.remove(file)

    def move(self, source: str, destination: str) -> bool:
        return self.driver.move(source, destination)

    def list(self, path: str) -> bool:
        return self.driver.list(path)



from equipment.framework.Config.AbstractConfig import AbstractConfig
from equipment.framework.Log.AbstractLog import AbstractLog
from equipment.framework.Log.GELFLog import GELFLog
from equipment.framework.Log.LocalLog import LocalLog
from equipment.framework.Log.ConsoleLog import ConsoleLog
from equipment.framework.Log.NoneLog import NoneLog
from icecream import ic


class LogFactory(AbstractLog):
    def __init__(self, config: AbstractConfig):
        driver_name = config.get('LOG', 'driver')

        if driver_name == 'local':
            self.driver = LocalLog(config)
        elif driver_name == 'console':
            self.driver = ConsoleLog(config)
        elif driver_name == 'gelf':
            self.driver = GELFLog(config)
        elif driver_name == 'none':
            self.driver = NoneLog(config)
        else:
            error = f'Log driver "{driver_name}" is not supported'
            ic.configureOutput(prefix='')
            ic(error)
            raise NotImplementedError(error)

    def debug(self, *args, **kwargs) -> None:
        self.driver.debug(*args, **kwargs)

    def info(self, *args, **kwargs) -> None:
        self.driver.info(*args, **kwargs)

    def warning(self, *args, **kwargs) -> None:
        self.driver.warning(*args, **kwargs)

    def error(self, *args, **kwargs) -> None:
        self.driver.error(*args, **kwargs)

    def critical(self, *args, **kwargs) -> None:
        self.driver.critical(*args, **kwargs)

    def get_handlers(self) -> list:
        return self.driver.get_handlers()

    def get_level(self) -> int:
        return self.driver.get_level()

    def get_name(self) -> str:
        return self.driver.get_name()



import unittest
from equipment.framework.Mail.Email.HTMLEmailFactory import HTMLEmailFactory
from equipment.framework.Mail.AbstractMail import AbstractMail
from equipment.framework.tests.TestCase import TestCase


class AbstractMailTest(TestCase):
    def test_abstract_methods(self):
        class TestMail(AbstractMail):
            pass

        with self.assertRaises(NotImplementedError):
            class MyEmail(HTMLEmailFactory):
                subject = 'My Email Subject'
                text = 'My Email Text'
                html = '<p>My Email <b>HTML</b></p>'
                sender = 'sender@example.com'
                recipients = ['test@test.com']
                cc = ['cc@example.com']
                bcc = ['bcc@example.com']
                attachments = {}

            TestMail().send(MyEmail())


if __name__ == '__main__':
    unittest.main()



from equipment.framework.Log.AbstractLog import AbstractLog
from equipment.framework.Config.AbstractConfig import AbstractConfig
from equipment.framework.Mail.AbstractMail import AbstractMail
from typing import Union
from equipment.framework.Mail.Email.Email import Email
from equipment.framework.Mail.Email.EmailFactory import EmailFactory
from pprint import pformat


class LogMail(AbstractMail):
    def __init__(self, config: AbstractConfig, log: AbstractLog):
        self.config = config
        self.log = log

    def send(self, email: Union[Email, EmailFactory]) -> bool:
        if isinstance(email, EmailFactory):
            email = email.make()

        self.log.info(pformat({
            'subject': email.subject,
            'text': email.text,
            'html': email.html,
            'sender': email.sender,
            'recipients': email.recipients,
            'cc': email.cc,
            'bcc': email.bcc,
            'attachments': email.attachments,
            'encoding': email.encoding,
        }, width=self.config.get('MAIL_LOG', 'width')))

        return True



from importlib import import_module
from inspect import getfile
from pathlib import Path
from typing import Any, NoReturn, Optional
from sys import exit as _exit, modules as _modules
from pprint import pformat
from dependency_injector.containers import Container
from equipment.framework.Exceptions.ContainerModuleNotFound import ContainerModuleNotFound


def app(name: str = 'app.App.Container', autodiscover: bool = True) -> Container:
    resolved_module = module(name)
    
    # Fallback framework module
    if autodiscover and resolved_module is None:
        resolved_module = module('equipment.framework.App.Container')

    raise_if(resolved_module is None, ContainerModuleNotFound(name))

    return resolved_module.Container


def base_path(join: Optional[str] = None, container: Optional[Container] = None) -> Path:
    if container is None:
        container = app()

    # We assume containers always leave under ./app/App/Container
    return Path(getfile(container)).parent.parent.parent.absolute().joinpath(
        join if join is not None else ''
    )


def module(name: str, print_exception: bool = False) -> Any:
    try:
        return import_module(name) if name not in _modules else _modules[name]
    except Exception as e:
        print_if(print_exception, e)
        return None


def raise_if(condition: bool, exception: Exception) -> None:
    if condition:
        raise exception


def raise_unless(condition: bool, exception: Exception) -> None:
    if not condition:
        raise exception


def print_if(condition: bool, *args, **kwargs) -> None:
    if condition:
        print(*args, **kwargs)


def print_unless(condition: bool, *args, **kwargs) -> None:
    if not condition:
        print(*args, **kwargs)


def dump(*args, **kwargs) -> None:
    pformat(*args, **kwargs)


def dd(*args, **kwargs) -> NoReturn:
    dump(*args, **kwargs)
    _exit()



import abc
from datetime import datetime


class AbstractQueue(abc.ABC):
    def push(self, method, *args, **kwargs) -> bool:
        raise NotImplementedError

    def pushOn(self, date: datetime, method, *args, **kwargs) -> bool:
        raise NotImplementedError



import unittest
from equipment.framework.tests.TestCase import TestCase
from equipment.framework.helpers import raise_if


class RaseIfHelperTest(TestCase):
    def test_true(self):
        with self.assertRaises(ImportError):
            raise_if(True, ImportError('foo'))

    def test_false(self):
        self.assertIsNone(raise_if(False, ImportError('foo')))


if __name__ == '__main__':
    unittest.main()



import unittest
import boto3
from moto import mock_ses
from equipment.framework.Mail.Email.HTMLEmailFactory import HTMLEmailFactory
from equipment.framework.Mail.AbstractMail import AbstractMail
from equipment.framework.Mail.SESMail import SESMail
from equipment.framework.tests.TestCase import TestCase


class SESMailTest(TestCase):
    def setUp(self):
        super().setUp()
        self.mail = SESMail(
            config=self.app.config(),
            log=self.app.log(),
        )

    def test_extends_from_abstract_Mail(self):
        with self.app.mail.override(self.mail):
            self.assertTrue(
                isinstance(self.app.mail(), AbstractMail)
            )

    @mock_ses
    def test_send_email_without_attachments(self):
        with self.app.mail.override(self.mail):
            self.app.mail().client = boto3.client('ses', region_name='us-east-1')
            self.app.mail().client.verify_email_address(EmailAddress='sender@example.com')

            class MyEmail(HTMLEmailFactory):
                subject = 'My Email Subject'
                text = 'My Email Text'
                html = '<p>My Email <b>HTML</b></p>'
                sender = 'sender@example.com'
                recipients = ['test@test.com']
                cc = ['cc@example.com']
                bcc = ['bcc@example.com']
                attachments = {}

            self.assertTrue(
                self.app.mail().send(MyEmail())
            )

    '''
    @mock_ses
    def test_send_email_with_attachments(self):
        with self.app.mail.override(self.mail):
            self.app.mail().client = boto3.client('ses')
            self.app.mail().client.verify_email_address(EmailAddress='sender@example.com')

            class MyEmail(HTMLEmailFactory):
                subject = 'My Email Subject'
                text = 'My Email Text'
                html = '<p>My Email <b>HTML</b></p>'
                sender = 'sender@example.com'
                recipients = ['test@test.com']
                cc = ['cc@example.com']
                bcc = ['bcc@example.com']
                attachments = {
                    TODO: SESEmail attachments support
                }

            self.assertTrue(
                self.app.mail().send(MyEmail())
            )
    '''


if __name__ == '__main__':
    unittest.main()



from sqlalchemy import create_engine
from equipment.framework.Config.AbstractConfig import AbstractConfig
from equipment.framework.Connection.SQLAlchemyConnection import SQLAlchemyConnection
from equipment.framework.Log.AbstractLog import AbstractLog


class MySQLConnection(SQLAlchemyConnection):
    def __init__(self, config: AbstractConfig, log: AbstractLog, name: str = 'CONNECTION_MYSQL'):
        super().__init__(config=config, log=log)
        self.name = name

    def connect(self) -> bool:
        try:
            self.connection = '''mysql+mysqldb://{username}:{password}@{host}:{port}/{db}?charset={charset}'''.format(
                username=self.config.get(self.name, 'username'),
                password=self.config.get(self.name, 'password'),
                host=self.config.get(self.name, 'host'),
                port=self.config.get(self.name, 'port'),
                db=self.config.get(self.name, 'db'),
                charset=self.config.get(self.name, 'charset'),
            )

            self.engine = create_engine(self.connection)

            return True
        except Exception as e:
            self.log.error(e, exc_info=True)
            return False



import abc
from equipment.framework.helpers import app


class AbstractJob(abc.ABC):
    @classmethod
    def dispatchSync(cls, *args, **kwargs) -> None:
        cls.app = app()  # nopep8
        cls.handle(*args, **kwargs)

    @classmethod
    def dispatch(cls, *args, **kwargs) -> None:
        app().queue().push(cls.dispatchSync, *args, **kwargs)  # nopep8

    @classmethod
    def dispatchWithContainer(cls, container, *args, **kwargs) -> None:
        container.queue().push(cls.dispatchSync, *args, **kwargs)  # nopep8

    @classmethod
    def handle(cls, *args, **kwargs) -> None:
        raise NotImplementedError



#!/usr/bin/env python

from datetime import datetime
from flask import Flask
from flask_wtf.csrf import CSRFProtect
from equipment.framework import equipment


app = Flask(__name__)
csrf = CSRFProtect(app)

app.equipment = equipment()

log = app.equipment.log()
config = app.equipment.config()

log.info(
    f'''

    Welcome to {config.get('APP', 'name')}

    To run the web server on production run
    the following command, based on your OS:

    Linux:
    $ pip install -r requirements.txt
    $ waitress-serve --listen *:8000 web:app

    Windows:
    $ pip install -r .\\requirements.txt
    $ waitress-serve.exe --listen *:8000 web:app
    '''
)


@app.route('/')
def landing():
    log.info('Logging from Flask route!')
    return f"<p>Welcome to <b>{config.get('APP', 'name')}</b> at {str(datetime.now())}</p>"


if __name__ == '__main__':
    app.run(
        host='0.0.0.0',
        port=8000
    )



import unittest
from equipment.framework.Storage.AbstractStorage import AbstractStorage
from equipment.framework.tests.TestCase import TestCase


class AbstractStorageTest(TestCase):
    def test_abstract_methods(self):
        class TestStorage(AbstractStorage):
            pass

        with self.assertRaises(NotImplementedError):
            TestStorage().write('a', 'b')

        with self.assertRaises(NotImplementedError):
            TestStorage().read('a')

        with self.assertRaises(NotImplementedError):
            TestStorage().exists('a')

        with self.assertRaises(NotImplementedError):
            TestStorage().remove('a')


if __name__ == '__main__':
    unittest.main()



import unittest
from app.Mail.WelcomeEmail import WelcomeEmail
from tests.TestCase import TestCase


class test_WelcomeMail(TestCase):
    def test_welcome_email(self):
        user_name = self.faker.name()

        factory = WelcomeEmail()
        factory.subject = 'Welcome'
        factory.sender = self.faker.email()
        factory.recipients = self.faker.email()

        factory.user_name = user_name
        email = factory.make()

        self.assertIn(user_name, email.text)
        self.assertIn(user_name, email.html)


if __name__ == '__main__':
    unittest.main()



import unittest
import os
from faker import Faker


class TestCase(unittest.TestCase):
    def setUp(self):
        super().setUp()

        # Global faker instance
        self.faker = Faker()

        # Access tests base path
        self.tests_path = os.path.dirname(os.path.abspath(__file__))


if __name__ == '__main__':
    unittest.main()



import abc
from typing import Any


class AbstractEnvironment(abc.ABC):
    def get(self, key: str) -> Any:
        raise NotImplementedError

    def set(self, key: str, value) -> None:
        raise NotImplementedError

    def all(self) -> list:
        raise NotImplementedError



import unittest
from os import sep
from uuid import uuid4
import boto3
from moto import mock_s3
from equipment.framework.tests.TestCase import TestCase
from equipment.framework.Storage.AbstractStorage import AbstractStorage
from equipment.framework.Storage.S3Storage import S3Storage


class S3StorageTest(TestCase):
    def setUp(self):
        super().setUp()

        self.app.storage.override(S3Storage(
            config=self.app.config(),
            log=self.app.log()
        ))

    def test_extends_from_abstract_storage(self):
        self.assertTrue(
            isinstance(self.app.storage(), AbstractStorage)
        )

    @mock_s3
    def test_file_lifecycle(self):
        self.app.storage().client = boto3.client('s3', region_name='us-east-1')

        # We need to create the bucket since this is all in Moto's 'virtual' AWS account
        self.app.storage().client.create_bucket(
            Bucket=self.app.config().get('STORAGE_S3', 'aws_bucket')
        )

        path = str(uuid4())
        file = path + sep + str(uuid4()) + '.txt'
        content = str(uuid4())

        self.assertFalse(self.app.storage().exists(file))

        self.assertTrue(self.app.storage().write(file, content))

        self.assertTrue(self.app.storage().exists(file))
        self.assertEqual(self.app.storage().read(file), content)
        self.assertTrue(self.app.storage().remove(file))
        self.assertFalse(self.app.storage().exists(file))


if __name__ == '__main__':
    unittest.main()



from typing import Union
from boto3 import client
from equipment.framework.Log.AbstractLog import AbstractLog
from equipment.framework.Config.AbstractConfig import AbstractConfig
from equipment.framework.Mail.AbstractMail import AbstractMail
from equipment.framework.Mail.Email.Email import Email
from equipment.framework.Mail.Email.EmailFactory import EmailFactory


class SESMail(AbstractMail):
    def __init__(self, config: AbstractConfig, log: AbstractLog):
        self.config = config
        self.log = log
        self.log.debug('aws_endpoint:')
        self.log.debug(self.config.get('MAIL_SES', 'aws_endpoint'))
        self.client = None

    def load(self) -> None:
        if self.client is None:
            self.reload()

    def reload(self) -> None:
        self.client = client(
            service_name='ses',
            endpoint_url=self.config.get('MAIL_SES', 'aws_endpoint'),
            region_name=self.config.get('MAIL_SES', 'aws_region'),
            aws_access_key_id=self.config.get(
                'MAIL_SES', 'aws_access_key_id'),
            aws_secret_access_key=self.config.get(
                'MAIL_SES', 'aws_secret_access_key'),
        )

    def send(self, email: Union[Email, EmailFactory]) -> bool:
        if isinstance(email, EmailFactory):
            email = email.make()

        return self._send_without_attachments(email) if len(email.attachments.keys()) == 0 else self._send_with_attachments(email)

    def _send_with_attachments(self, email: Email) -> bool:
        raise NotImplementedError

    def _send_without_attachments(self, email: Email) -> bool:
        try:
            self.load()

            response = self.client.send_email(
                Source=email.sender,
                Destination={
                    'ToAddresses': email.recipients,
                    'CcAddresses': email.cc,
                    'BccAddresses': email.bcc
                },
                Message={
                    'Subject': {
                        'Data': email.subject,
                        'Charset': email.encoding
                    },
                    'Body': {
                        'Text': {
                            'Data': email.text,
                            'Charset': email.encoding
                        },
                        'Html': {
                            'Data': email.html,
                            'Charset': email.encoding
                        }
                    }
                },
            )

            # for adding attachments support -> https://www.learnaws.org/2020/12/18/aws-ses-boto3-guide/#how-to-send-an-email-with-attachments-using-ses

            self.log.debug('Email sent! Message ID:')
            self.log.debug(response['MessageId'])

            return True
        except Exception as e:
            self.log.error(e, exc_info=True)
            return False



from datetime import datetime
import os
import unittest
from uuid import uuid4
from equipment.framework.Storage.AbstractStorage import AbstractStorage
from equipment.framework.Storage.LocalStorage import LocalStorage
from equipment.framework.tests.TestCase import TestCase


class LocalStorageTest(TestCase):
    def setUp(self):
        super().setUp()

        self.app.config().set('STORAGE_LOCAL', 'path', 'storage/test')

        self.app.storage.override(LocalStorage(
            config=self.app.config(),
            log=self.app.log()
        ))

    def test_extends_from_abstract_storage(self):
        self.assertTrue(
            isinstance(self.app.storage(), AbstractStorage)
        )

    def test_file_lifecycle(self):
        path = str(uuid4())
        file = path + os.path.sep + str(uuid4()) + '.txt'
        content = str(uuid4())

        self.assertFalse(self.app.storage().exists(file))
        self.assertTrue(self.app.storage().write(file, content))

        self.assertTrue(self.app.storage().exists(file))
        self.assertEqual(self.app.storage().read(file), content)

        new_file = os.path.splitext(file)[0] + datetime.now().strftime('.%Y-%m-%d_%H_%M_%S') + '.txt'   # nopep8

        self.assertFalse(self.app.storage().exists(new_file))
        self.assertTrue(self.app.storage().move(file, new_file))
        self.assertTrue(self.app.storage().exists(new_file))
        self.assertTrue(self.app.storage().remove(new_file))
        self.assertFalse(self.app.storage().exists(new_file))

        os.rmdir(self.app.storage().path(path))

    def test_list_files_in_directory(self):
        path = str(uuid4())
        number_of_files = 10
        files = [path + os.path.sep + str(uuid4()) + '.txt' for _ in range(number_of_files)]    # nopep8
        content = str(uuid4())

        for file in files:
            self.app.storage().write(file, content)

        self.assertIsInstance(self.app.storage().list(path), list)
        self.assertEqual(len(self.app.storage().list(path)), number_of_files)

        for file in files:
            self.app.storage().remove(file)

        os.rmdir(self.app.storage().path(path))


if __name__ == '__main__':
    unittest.main()



from equipment.framework.Mail.Email.Email import Email
from equipment.framework.Mail.Email.HTMLEmailFactory import HTMLEmailFactory
from html2text import html2text


class TextEmailFactory(HTMLEmailFactory):
    text = None  # type: str
    html = None  # type: None

    # pylint: disable=dangerous-default-value
    def render(self, template: str, parameters: dict = {}) -> None:
        self.load()

        self.text = html2text(
            self.jinja.get_template(template).render(parameters)
        )

    def make(self) -> Email:
        if self.text is None:
            raise ValueError('"text" cannot be None')

        self.html = None

        return super().make()



import unittest
from unittest.mock import MagicMock

from sqlalchemy.orm.session import Session
from equipment.framework.Connection.SQLAlchemyConnection import SQLAlchemyConnection
from equipment.framework.tests.TestCase import TestCase


class SQLAlchemyConnectionTest(TestCase):
    def setUp(self):
        super().setUp()
        self.sql = SQLAlchemyConnection(
            config=self.app.config(),
            log=self.app.log()
        )

    def test_abstract_methods(self):
        with self.assertRaises(NotImplementedError):
            self.sql.connect()

    def test_url_method(self):
        self.sql.engine = MagicMock()
        self.sql.connection = 'foo'

        self.assertEqual(
            self.sql.url(),
            'foo'
        )

    def test_session_method(self):
        self.sql.engine = MagicMock()
        self.sql.connection = 'foo'

        self.assertIsInstance(self.sql.session(), Session)


if __name__ == '__main__':
    unittest.main()



import abc


class AbstractStorage(abc.ABC):
    def base_path(self) -> str:
        raise NotImplementedError

    def path(self, file: str) -> str:
        raise NotImplementedError

    def write(self, file: str, data: str) -> bool:
        raise NotImplementedError

    def read(self, file: str) -> str:
        raise NotImplementedError

    def exists(self, file: str) -> bool:
        raise NotImplementedError

    def remove(self, file: str) -> bool:
        raise NotImplementedError

    def move(self, source: str, destination: str) -> bool:
        raise NotImplementedError

    def list(self, path: str) -> list:
        raise NotImplementedError



import abc
from typing import Optional, Union
from equipment.framework.Mail.Email.Email import Email


class EmailFactory(abc.ABC):
    subject = None  # type: str
    text = None  # type: Optional[str]
    html = None  # type: Optional[str]
    sender = None  # type: str
    recipients = None  # type: Union[list,str]
    cc = None  # type: list
    bcc = None  # type: list
    attachments = None  # type: dict
    encoding = None  # type: str

    # pylint: disable=dangerous-default-value
    def render(self, template: str, parameters: dict = {}) -> None:
        raise NotImplementedError

    def make(self) -> Email:
        data = {
            'subject': self.subject,
            'text': self.text,
            'html': self.html,
            'sender': self.sender,
            'recipients': self.recipients,
            'cc': self.cc,
            'bcc': self.bcc,
            'attachments': self.attachments,
            'encoding': self.encoding
        }

        if 'recipients' not in data:
            raise ValueError('''
            "recipients" should be a list or a str with email addresses
            ''')

        if isinstance(data['recipients'], str):
            data['recipients'] = [data['recipients']]

        if 'cc' not in data or data['cc'] is None:
            data['cc'] = []

        if 'bcc' not in data or data['bcc'] is None:
            data['bcc'] = []

        if 'attachments' not in data or data['attachments'] is None:
            data['attachments'] = {}

        if 'encoding' not in data or data['encoding'] is None:
            data['encoding'] = 'UTF-8'

        if ('html' not in data or data['html'] is None) and ('text' not in data or data['text'] is None):
            raise ValueError('''
            "html" and "text" fields cannot be None at the same time.
            At least one of both should contain the email content
            ''')

        return Email(data)



import os
from typing import Any
from dotenv import load_dotenv
from equipment.framework.Environment.AbstractEnvironment import AbstractEnvironment
from equipment.framework.helpers import base_path


class LocalEnvironment(AbstractEnvironment):
    def __init__(self, relative_path: str = '.env'):
        self.path = os.path.join(
            os.path.dirname(os.path.realpath(__file__)),
            str(base_path(relative_path))
        )

        load_dotenv(dotenv_path=self.path)

    def get(self, key: str) -> Any:
        return os.environ.get(key)

    def set(self, key: str, value) -> None:
        os.environ[key] = value

    def all(self) -> list:
        return [{item: os.environ.get(item)} for item in os.environ]



import unittest
from equipment.framework.Jobs.AbstractJob import AbstractJob
from app.Jobs.ExampleJob import ExampleJob
from tests.TestCase import TestCase


class test_ExampleJob(TestCase):
    def test_extends_from_abstract_job(self):
        self.assertTrue(
            isinstance(ExampleJob(), AbstractJob)
        )


if __name__ == '__main__':
    unittest.main()



import unittest
from uuid import uuid4
from equipment.framework.Log.AbstractLog import AbstractLog
from equipment.framework.Log.NoneLog import NoneLog
from equipment.framework.tests.TestCase import TestCase


class NoneLogTest(TestCase):
    def setUp(self):
        super().setUp()
        self.log = NoneLog(self.app.config())

    def test_extends_from_abstract_log(self):
        with self.app.log.override(self.log):
            self.assertTrue(
                isinstance(self.app.log(), AbstractLog)
            )

    def test_returns_none(self):
        with self.app.log.override(self.log):
            message = str(uuid4())

            self.assertIsNone(
                self.app.log().debug(message)
            )

            self.assertIsNone(
                self.app.log().info(message)
            )

            self.assertIsNone(
                self.app.log().warning(message)
            )

            self.assertIsNone(
                self.app.log().error(message)
            )

            self.assertIsNone(
                self.app.log().critical(message)
            )


if __name__ == '__main__':
    unittest.main()



#!/usr/bin/env python

from equipment.framework import equipment

app = equipment()

app.log().info(
    f'''

    Welcome to {app.config().get('APP', 'name')}

    Do you need to run scheduled tasks?

    $ pip install -r requirements.txt
    $ py scheduler.py

    Do you need to enqueue tasks?

    $ pip install -r requirements.txt
    $ rq worker --with-scheduler --url redis://localhost:6379/0

    Do you need to run a web server?

    Linux:
    $ pip install -r requirements.txt
    $ waitress-serve --listen *:8000 web:app

    Windows:
    $ pip install -r .\\requirements.txt
    $ waitress-serve.exe --listen *:8000 web:app

    Check other examples on ./examples directory
    '''
)



"""create example table

Revision ID: 0797374c92af
Revises:
Create Date: 2021-06-07 14:58:43.762044

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = '0797374c92af'
down_revision = None
branch_labels = None
depends_on = None


def upgrade():
    op.create_table(
        'example',
        sa.Column('id', sa.Integer, primary_key=True),
        sa.Column('name', sa.String(50), nullable=False),
        sa.Column('description', sa.Unicode(200)),
    )


def downgrade():
    op.drop_table('example')



import abc
from typing import Union
from equipment.framework.Mail.Email.Email import Email
from equipment.framework.Mail.Email.EmailFactory import EmailFactory


class AbstractMail(abc.ABC):
    def send(self, email: Union[Email, EmailFactory]) -> bool:
        raise NotImplementedError



import unittest
from equipment.framework.Jobs.AbstractJob import AbstractJob
from equipment.framework.tests.TestCase import TestCase
from equipment.framework.helpers import app


class AbstractJobTest(TestCase):
    def test_dispatch(self):
        class TestJob(AbstractJob):
            pass

        self.assertIsNone(TestJob().dispatchWithContainer(app('equipment.framework.App.Container'), 1, 2, 3))  # nopep8


if __name__ == '__main__':
    unittest.main()



from dependency_injector.containers import Container
from equipment.framework.helpers import app


def equipment(name: str = 'app.App.Container', autodiscover: bool = True) -> Container:
    return app(name, autodiscover)



import sys
from setuptools import setup

install_requires = []

with open('equipment/console/requirements.txt', 'r', encoding='utf-8') as f:
    install_requires.extend(f.read().splitlines())

with open('equipment/framework/requirements.txt', 'r', encoding='utf-8') as f:
    install_requires.extend(f.read().splitlines())

with open('README.md', 'r', encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='equipment',
    packages=['equipment'],
    version='0.0.13',
    license='MIT',
    description='The root of your next python project',
    long_description=long_description,
    long_description_content_type='text/markdown',
    author='Roger Vilà',
    author_email='rogervila@me.com',
    url='https://github.com/rogervila/equipment',
    download_url='https://github.com/rogervila/equipment/archive/0.0.13.tar.gz',
    keywords=['equipment', 'application scaffolding', 'framework'],
    install_requires=install_requires,
    tests_require=['coverage', 'runtype'],
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3.8',
    ],
    include_package_data=True,
    entry_points={
        # Install a script as "equipment", and as "equipment3", and as "equipment3.x"
        'console_scripts': [
            #pylint: disable=consider-using-f-string
            'equipment = equipment.console:main',
            'equipment%d = equipment.console:main' % sys.version_info[:1],
            'equipment%d.%d = equipment.console:main' % sys.version_info[:2],
            #pylint: enable=consider-using-f-string
        ],
    },
)



from click import echo
from equipment.console.Commands.AbstractCommand import AbstractCommand


class ExampleCommand(AbstractCommand):
    def __init__(self) -> None:
        pass # Constructor is not extended from AbstractCommand. You are free to pass any parameter to it

    def run(self, *args, **kwargs) -> None:
        echo('Running example command!')



import logging
from equipment.framework.Config.AbstractConfig import AbstractConfig
from equipment.framework.Log.AbstractLog import AbstractLog


class NativeLog(AbstractLog):
    def __init__(self, config: AbstractConfig):
        self.handlers = None
        self.format = None
        self.level = None
        self.name = None
        self.date_format = None
        self.logger = None
        self.config = config

    def load(self) -> None:
        if self.logger is None:
            self.reload()

    def reload(self) -> None:
        self.handlers = self.get_handlers()
        self.format = '[%(asctime)s] %(name)s.%(levelname)s %(message)s'
        self.level = self.get_level()
        self.name = self.get_name()
        self.date_format = '%Y-%m-%d %H:%M:%S'

        logging.basicConfig(
            format=self.format,
            level=self.level,
            datefmt=self.date_format,
            handlers=self.handlers
        )

        self.logger = logging.getLogger(self.name)

    def debug(self, *args, **kwargs) -> None:
        self.load()
        self.logger.debug(*args, **kwargs)

    def info(self, *args, **kwargs) -> None:
        self.load()
        self.logger.info(*args, **kwargs)

    def warning(self, *args, **kwargs) -> None:
        self.load()
        self.logger.warning(*args, **kwargs)

    def error(self, *args, **kwargs) -> None:
        self.load()
        self.logger.error(*args, **kwargs)

    def critical(self, *args, **kwargs) -> None:
        self.load()
        self.logger.critical(*args, **kwargs)



from typing import Optional
from py_dto import DTO


class Email(DTO):
    subject: str
    text: Optional[str]
    html: Optional[str]
    sender: str
    recipients: list
    cc: list
    bcc: list
    attachments: dict
    encoding: str



import unittest
from unittest.mock import MagicMock
from equipment.framework.Queue.AbstractQueue import AbstractQueue
from equipment.framework.Queue.RedisQueue import RedisQueue
from equipment.framework.tests.TestCase import TestCase


class RedisQueueTest(TestCase):
    def setUp(self):
        super().setUp()
        self.queue = RedisQueue(
            config=self.app.config(),
            log=self.app.log(),
        )

    def test_extends_from_abstract_queue(self):
        with self.app.queue.override(self.queue):
            self.assertTrue(
                isinstance(self.app.queue(), AbstractQueue)
            )

    def test_enqueues_methods(self):
        with self.app.queue.override(self.queue):
            def method_test():
                return True

            self.queue.redis = MagicMock()
            self.queue.queue = MagicMock()

            self.assertTrue(
                self.queue.push(method_test)
            )

            self.queue.queue.enqueue = MagicMock(side_effect=Exception())

            self.assertFalse(
                self.queue.push(method_test)
            )


if __name__ == '__main__':
    unittest.main()



from equipment.framework.Jobs.AbstractJob import AbstractJob


class _REPLACEME_(AbstractJob):
    @classmethod
    def handle(cls, *args, **kwargs) -> None:
        app = cls.app

        app.log().debug(args)
        app.log().debug(kwargs)



#!/usr/bin/env python

import sys
from inspect import getmembers
from os import getcwd
import click
from equipment.console.Commands.MakeJobCommand import MakeJobCommand
from equipment.console.Commands.NewCommand import NewCommand
from equipment.framework.helpers import module


@click.group()
@click.version_option()
def main() -> None:
    pass  # @click decorators handle the commands defined on this file


@main.command()
@click.argument('name')
def new(name):
    NewCommand(name).run()


@main.group()
def make() -> None:
    pass  # @click decorators handle the commands defined on this file


@make.command()
@click.argument('name')
def job(name):
    MakeJobCommand(name).run()


# Add project commands if available
sys.path.append(getcwd())
project_commands_module = module(
    'app.Commands.commands',
    print_exception=False
)

if project_commands_module is not None:
    for member in getmembers(project_commands_module):
        if not isinstance(member[1], click.Command):
            continue

        try:
            main.add_command(getattr(project_commands_module, member[0]))
        except Exception:
            pass  # Error messages here do not provide any value and break the console developer experience

if __name__ == '__main__':
    main()



from redis import Redis
from equipment.framework.Config.AbstractConfig import AbstractConfig
from equipment.framework.Connection.AbstractConnection import AbstractConnection
from equipment.framework.Log.AbstractLog import AbstractLog


class RedisConnection(AbstractConnection):
    def __init__(self, config: AbstractConfig, log: AbstractLog, name: str = 'CONNECTION_REDIS'):
        self.config = config
        self.log = log
        self.redis = None
        self.name = name

    def load(self) -> None:
        if self.redis is None:
            self.reload()

    def reload(self) -> None:
        self.connect()

    def connect(self) -> bool:
        try:
            self.redis = Redis(
                host=self.config.get(self.name, 'host'),
                port=self.config.get(self.name, 'port'),
                db=self.config.get(self.name, 'db'),
            )

            self.log.debug(self.redis)

            return True
        except Exception as e:
            self.log.error(e, exc_info=True)
            return False

    def factory(self) -> Redis:
        self.load()

        return self.redis



import abc
from typing import Any


class AbstractConfig(abc.ABC):
    def load(self) -> None:
        raise NotImplementedError

    def reload(self) -> None:
        raise NotImplementedError

    def set(self, section: str, key: str, value) -> None:
        raise NotImplementedError

    def get(self, section: str, key: str) -> Any:
        raise NotImplementedError



from dependency_injector.containers import DeclarativeContainer
from dependency_injector.providers import Singleton
from equipment.framework.Config.ConfigFactory import ConfigFactory
from equipment.framework.Environment.EnvironmentFactory import EnvironmentFactory
from equipment.framework.Log.LogFactory import LogFactory
from equipment.framework.Mail.MailFactory import MailFactory
from equipment.framework.Queue.QueueFactory import QueueFactory
from equipment.framework.Storage.StorageFactory import StorageFactory

'''
The Application Container uses dependency-injector
under the hood.
'''


class Container(DeclarativeContainer):
    '''The Application Container'''

    environment = Singleton(EnvironmentFactory)
    '''The environment'''

    config = Singleton(ConfigFactory, environment)
    log = Singleton(LogFactory, config)
    queue = Singleton(QueueFactory, config, log)
    storage = Singleton(StorageFactory, config, log)
    mail = Singleton(MailFactory, config, log)



import unittest
import os
from unittest.mock import patch
from shutil import rmtree
from os.path import isfile
from click.testing import CliRunner
from equipment.console.Commands.MakeJobCommand import MakeJobCommand
from equipment.console import job
from equipment.console.tests.TestCase import TestCase


class MakeJobCommandTest(TestCase):
    def _cleanup(self) -> None:
        rmtree(f'{self.tests_path}{os.sep}app', ignore_errors=True)

    def setUp(self) -> None:
        super().setUp()
        self._cleanup()

    def tearDown(self) -> None:
        super().tearDown()
        self._cleanup()

    def test_command_invoke(self):
        name = '__pycache__'  # ensure it is always ignored

        with patch.object(os, 'getcwd', return_value=self.tests_path):
            runner = CliRunner()
            result = runner.invoke(job, [name])
            self.assertTrue(result.exit_code == 0)

    def test_command_class(self):
        name = '__pycache__'  # ensure it is always ignored
        full_path = f'{self.tests_path}{os.sep}app{os.sep}Jobs{os.sep}{name}.py'

        self.assertFalse(isfile(full_path))

        with patch.object(os, 'getcwd', return_value=self.tests_path):
            self.assertIsNone(MakeJobCommand(name).run())

        self.assertTrue(isfile(full_path))


if __name__ == '__main__':
    unittest.main()



from equipment.framework.Log.AbstractLog import AbstractLog
from equipment.framework.Config.AbstractConfig import AbstractConfig
from equipment.framework.Mail.AbstractMail import AbstractMail
from equipment.framework.Mail.SMTPMail import SMTPMail
from equipment.framework.Mail.SESMail import SESMail
from equipment.framework.Mail.LogMail import LogMail
from typing import Union
from equipment.framework.Mail.Email.Email import Email
from equipment.framework.Mail.Email.EmailFactory import EmailFactory


class MailFactory(AbstractMail):
    def __init__(self, config: AbstractConfig, log: AbstractLog):
        driver_name = config.get('MAIL', 'driver')

        if driver_name == 'smtp':
            self.driver = SMTPMail(config, log)
        elif driver_name == 's3':
            self.driver = SESMail(config, log)
        elif driver_name == 'log':
            self.driver = LogMail(config, log)
        else:
            error = f'Mail driver "{driver_name}" is not supported'
            log.error(error)
            raise NotImplementedError(error)

    def send(self, email: Union[Email, EmailFactory]) -> bool:
        return self.driver.send(email)



from boto3 import client
from botocore.errorfactory import ClientError
from equipment.framework.Config.AbstractConfig import AbstractConfig
from equipment.framework.Log.AbstractLog import AbstractLog
from equipment.framework.Storage.AbstractStorage import AbstractStorage


class S3Storage(AbstractStorage):
    def __init__(self, config: AbstractConfig, log: AbstractLog):
        self.config = config
        self.log = log
        self.client = None

    def load(self) -> None:
        if self.client is None:
            self.reload()

    def reload(self) -> None:
        self.client = client(
            service_name='s3',
            endpoint_url=self.config.get('STORAGE_S3', 'aws_endpoint'),
            region_name=self.config.get('STORAGE_S3', 'aws_region'),
            aws_access_key_id=self.config.get(
                'STORAGE_S3', 'aws_access_key_id'),
            aws_secret_access_key=self.config.get(
                'STORAGE_S3', 'aws_secret_access_key'),
        )

    def path(self, file: str) -> str:
        raise NotImplementedError  # TODO

    def write(self, file: str, data: str) -> bool:
        try:
            self.load()
            self.client.put_object(
                Bucket=self.config.get('STORAGE_S3', 'aws_bucket'),
                Key=file,
                Body=data
            )

            return True
        except Exception as e:
            self.log.error(e, exc_info=True)
            return False

    def read(self, file: str) -> str:
        self.load()

        self.log.debug('S3Storage@read file: ' + file)

        result = self.client.get_object(
            Bucket=self.config.get('STORAGE_S3', 'aws_bucket'),
            Key=file,
        )

        return result['Body'].read().decode(self.config.get('STORAGE_S3', 'aws_decode'))

    def exists(self, file: str) -> bool:
        try:
            self.load()

            self.client.head_object(
                Bucket=self.config.get('STORAGE_S3', 'aws_bucket'),
                Key=file,
            )
            return True
        except ClientError as e:
            if e.response['ResponseMetadata']['HTTPStatusCode'] == 404:
                return False

            self.log.error(e, exc_info=True)
            raise e

    def remove(self, file: str) -> bool:
        try:
            self.load()

            self.client.delete_object(
                Bucket=self.config.get('STORAGE_S3', 'aws_bucket'),
                Key=file,
            )
            return True
        except Exception as e:
            self.log.error(e, exc_info=True)
            return False
